#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-entity-map
version:              0.1.0.0
visibility:           public
id:                   html-entity-map-0.1.0.0-3yYvHjxorwdETMlEeNFddP
key:                  html-entity-map-0.1.0.0-3yYvHjxorwdETMlEeNFddP
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/html-entity-map
synopsis:
    Map from HTML5 entity names to the corresponding Unicode text

description:
    Map from HTML5 entity names to the corresponding Unicode text.

category:             HTML
abi:                  4f2af3102814ba2054b277a687119ee7
exposed:              True
exposed-modules:      Data.HTML.Entities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/html-entity-map-0.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/html-entity-map-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/html-entity-map-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-entity-map
hs-libraries:         HShtml-entity-map-0.1.0.0-3yYvHjxorwdETMlEeNFddP
depends:
    base-4.18.2.1 text-2.0.2
    unordered-containers-0.2.20.1-FX7g4DMKoiaDV91wUmRzTu

haddock-interfaces:
    /usr/share/doc/haskell-html-entity-map/html/html-entity-map.haddock

haddock-html:         /usr/share/doc/haskell-html-entity-map/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

